﻿using System;
using System.Drawing;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.WinForms;

namespace _9315
{
    class CustomToolTip
    {
        public Timer ToolTipTimer { get; set; }
        public int XOffset { get; set; }
        public int YOffset { get; set; }        
        public WinformsMap MapControl { get; set; }
        public string tooltipText { get; set; }
        public PointShape latestPoint { get; set; }

        private Label label;
        private Control HoverControl { get; set; }
        private Timer RemoveToolTipTimer { get; set; }

        public CustomToolTip()
        {
            XOffset = 20;
            YOffset = 0;
            ToolTipTimer = new Timer();
            RemoveToolTipTimer = new Timer();
            label = new Label();
            tooltipText = string.Empty;
            latestPoint = new PointShape();

            ToolTipTimer.Tick += new EventHandler(ToolTipTimer_Tick);
            RemoveToolTipTimer.Tick += new EventHandler(RemoveToolTipTimer_Tick);
        }

        void ToolTipTimer_Tick(object sender, EventArgs e)
        {
            DisplayToolTip();
            ToolTipTimer.Stop();
            RemoveToolTipTimer.Stop();
            RemoveToolTipTimer.Start();
        }

        void RemoveToolTipTimer_Tick(object sender, EventArgs e)
        {
            MapControl.Controls.Remove(HoverControl);
            RemoveToolTipTimer.Stop();
        }

        private void DisplayToolTip()
        {
            ScreenPointF currentScreenPoint = ExtentHelper.ToScreenCoordinate(MapControl.CurrentExtent, latestPoint, MapControl.Width, MapControl.Height);
            {
                if (HoverControl != null)
                {
                    HoverControl.Hide();
                    HoverControl.Location = new Point((int)(currentScreenPoint.X + XOffset), (int)(currentScreenPoint.Y + YOffset));
                    HoverControl.Show();
                    MapControl.Controls.Add(HoverControl);
                }
                else
                {
                    label.Text = tooltipText;
                    HoverControl = label;
                    HoverControl.Location = new Point((int)(currentScreenPoint.X + XOffset), (int)(currentScreenPoint.Y + YOffset));
                    MapControl.Controls.Add(HoverControl);
                }
            }
        }
    }
}
