﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace _9315
{
    public partial class Form1 : Form
    {
        private CustomToolTip mapToolTip = new CustomToolTip();
        
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;

            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\AppData\states.shp");
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = WorldStreetsAreaStyles.Military();
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


            layerOverlay.Layers.Add(shapeFileLayer);
            winformsMap1.Overlays.Add(layerOverlay);

            shapeFileLayer.Open();
            winformsMap1.CurrentExtent = shapeFileLayer.GetBoundingBox();

            GenerateSampleVehicle(shapeFileLayer.GetBoundingBox());
            mapToolTip.MapControl = winformsMap1;

            winformsMap1.Refresh();
        }

        private void GenerateSampleVehicle(RectangleShape rect)
        {
            PointShape ulp = rect.UpperLeftPoint;
            PointShape lrp = rect.LowerRightPoint;
            Random r = new Random();
            PointShape randomP1 = new PointShape(r.Next((int)ulp.X, (int)lrp.X), r.Next((int)lrp.Y, (int)ulp.Y));

            Feature marker1 = new Feature(randomP1);
            marker1.ColumnValues.Add("Text", "It's a tooltip");

            LayerOverlay overlay = new LayerOverlay();

            InMemoryFeatureLayer imf = new InMemoryFeatureLayer();
            imf.Open();
            imf.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(new GeoImage(@"..\..\AppData\car.png"));
            imf.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            imf.InternalFeatures.Add(marker1);
            overlay.Layers.Add("ShapeLayer", imf);
            winformsMap1.Overlays.Add("ShapeOverlay", overlay);
        }

        private void winformsMap1_MouseMove(object sender, MouseEventArgs e)
        {
            if (!mapToolTip.ToolTipTimer.Enabled)
            {
                PointShape currentWorldPoint = ExtentHelper.ToWorldCoordinate(winformsMap1.CurrentExtent, e.X, e.Y, winformsMap1.Width, winformsMap1.Height);

                InMemoryFeatureLayer shapeLayer = (InMemoryFeatureLayer)winformsMap1.FindFeatureLayer("ShapeLayer");
                Collection<Feature> fs = shapeLayer.QueryTools.GetFeaturesNearestTo(currentWorldPoint, GeographyUnit.Meter, 1, ReturningColumnsType.AllColumns);

                if (fs.Count > 0)
                {
                    PointShape centerOfFeature = fs[0].GetShape() as PointShape;
                    mapToolTip.tooltipText = fs[0].ColumnValues["Text"];
                    mapToolTip.latestPoint = centerOfFeature;
                    double showTooltipTolerance = 5;
                    RectangleShape featureTargetArea = new RectangleShape(centerOfFeature.X - showTooltipTolerance, centerOfFeature.Y + showTooltipTolerance, centerOfFeature.X + showTooltipTolerance, centerOfFeature.Y - showTooltipTolerance);
                    if (featureTargetArea.Contains(currentWorldPoint))
                    {
                        mapToolTip.ToolTipTimer.Start();
                    }
                }
            }
        }
    }
}
